#' fingertipscharts: A package for creating the visualisations displayed in Fingertips
#'
#' The fingertipscharts package provides one type of function
#'
#' @section quick charts functions: Easy to produce Fingertips charts using
#'   tidyverse syntax
#' @docType package
#' @name fingertipscharts
NULL
globalVariables(c(':=',
                  'Best',
                  'England',
                  'GraphPoint',
                  'Q0',
                  'Q100',
                  'Worst',
                  'areavalue',
                  'highlight',
                  'hole',
                  'ind',
                  'label',
                  'middle',
                  'no_domains',
                  'percent_na',
                  'regionalvalue',
                  'reverse',
                  'tp',
                  'val',
                  'x',
                  'xmax',
                  'xmin',
                  'y',
                  'y25',
                  'y5',
                  'y50',
                  'y75',
                  'y95',
                  'ymax',
                  'ymin',
                  'Count',
                  'Denominator',
                  'EngVal',
                  'IndicatorName',
                  'LCI',
                  'ParentAreaCode',
                  'Polarity',
                  'Timeperiod',
                  'UCI',
                  'Value'))
